
use pubs2
go

if object_id(N'dbo.insert_authors', 'P') is not null
	drop procedure dbo.insert_authors
if object_id(N'dbo.insert_titles', 'P') is not null
	drop procedure dbo.insert_titles
if object_id(N'dbo.insert_titleauthor', 'P') is not null
	drop procedure dbo.insert_titleauthor

if object_id(N'dbo.update_authors', 'P') is not null
	drop procedure dbo.update_authors
if object_id(N'dbo.update_titles', 'P') is not null
	drop procedure dbo.update_titles
if object_id(N'dbo.update_titleauthor', 'P') is not null
	drop procedure dbo.update_titleauthor
	
if object_id(N'dbo.delete_authors', 'P') is not null
	drop procedure dbo.delete_authors
if object_id(N'dbo.delete_titles', 'P') is not null
	drop procedure dbo.delete_titles
if object_id(N'dbo.delete_titleauthor', 'P') is not null
	drop procedure dbo.delete_titleauthor
go

create procedure insert_authors(
        @au_id varchar(11),
        @au_lname varchar(40),
		@au_fname varchar(20),
		@phone char(12),
		@address varchar(40) = NULL,
		@city varchar(20) = NULL,
		@state char(2) = NULL,
		@zip char(5) = NULL,
		@contract bit)  
as
begin
insert into authors (au_id, 
		au_lname,
		au_fname,
		phone,
		address,
		city,
		state,
		zip,
		[contract]) 
	values (@au_id,
	    @au_lname,
		@au_fname,
		@phone,
		@address,
		@city,
		@state,
		@zip,
		@contract);
end
go

create procedure insert_titles(
        @title_id tid,
		@title varchar(80),
		@type char(12),
		@pub_id char(4) = NULL,
		@price money = NULL,
		@advance money = NULL,
		@royalty int = NULL,
		@ytd_sales int = NULL,
		@notes varchar(200) = NULL,
		@pubdate datetime = NULL)  
as
begin
insert into titles ([title_id],
		[title],
		[type],
		pub_id,
		price,
		advance,
		royalty,
		ytd_sales,
		notes,
		pubdate) 
	values (@title_id, 
		@title,
		@type,
		@pub_id,
		@price,
		@advance,
		@royalty,
		@ytd_sales,
		@notes,
		@pubdate);
end
go

create procedure dbo.insert_titleauthor (
        @title_id tid ,
        @au_id varchar(11)
        )        
as
begin
insert into titleauthor (title_id, au_id) 
	values (@title_id, @au_id);
end
go

create procedure update_authors(
        @au_id varchar(11),
        @au_lname varchar(40),
		@au_fname varchar(20),
		@phone char(12),
		@address varchar(40) = NULL,
		@city varchar(20) = NULL,
		@state char(2) = NULL,
		@zip char(5) = NULL,
		@contract bit)  
as
begin
	update authors
    set au_lname = @au_lname,
		au_fname = @au_fname,
		phone = @phone,
		address = @address,
		city = @city,
		state = @state,
		zip = @zip,
		contract = @contract        
	where au_id = @au_id
end
go

create procedure update_titles(
        @title_id tid,
		@title varchar(80),
		@type char(12),
		@pub_id char(4) = NULL,
		@price money = NULL,
		@advance money = NULL,
		@royalty int = NULL,
		@ytd_sales int = NULL,
		@notes varchar(200) = NULL,
		@pubdate datetime = NULL)  
as
begin
	update titles
      set title = @title,
		type = @type,
		pub_id = @pub_id,
		price = @price,
		advance = @advance,
		royalty = @royalty,
		ytd_sales = @ytd_sales,
		notes = @notes,
		pubdate = @pubdate 
	where title_id = @title_id
end
go

create procedure dbo.update_titleauthor (
        @old_title_id tid ,
        @old_au_id varchar(11) ,
        @new_title_id tid ,
        @new_au_id varchar(11)
        )        
as
begin
	update titleauthor 
	set title_id = @new_title_id, au_id = @new_au_id
	where title_id = @old_title_id and au_id = @old_au_id;
end
go

create procedure dbo.delete_authors (
        @au_id varchar(11)
        )        
as
begin
	delete authors where au_id = @au_id;
end
go

create procedure dbo.delete_titles (
        @title_id tid
        )        
as
begin
	delete titles where title_id = @title_id;
end
go

create procedure dbo.delete_titleauthor (
        @title_id tid ,
        @au_id varchar(11)
        )        
as
begin
	delete titleauthor 
	where title_id = @title_id and au_id = @au_id;
end
go